import click
import presspy


@click.group()
def cli():
    "A Python Project Compression Software"
    pass


@cli.command()
@click.argument("file")
@click.option(
    "--keep",
    default=False,
    is_flag=True,
    help="Keeps the source program after running in a folder.",
)
def run(file, keep):
    "Runs a .press file."
    print("Running")
    presspy.run(file, keep)


@cli.command()
@click.argument("path")
def press(path):
    "Presses a Python program into a .press file."
    presspy.press(path)


@cli.command()
@click.argument("file")
def extract(file):
    "Puts source of .press file into folder."
    presspy.extract(file)



import os
import time
import shutil
import json
import sys
import pkg_resources
from zipfile import ZipFile


def info():
    print("PressPy Compression Software")
    print("Designed by BD103")
    print("Version: " + pkg_resources.get_distribution(__name__).version)
    print('Enter "presspy" for help')


def extract(file):
    # Starts timer
    start_time = time.time()

    # Extract program files
    print("Extracting program files")
    archive = ZipFile(file, "r")
    os.mkdir("program")
    os.chdir("program")
    archive.extractall()

    # Gets meta
    print("Reading meta file")
    with open("press.json", "r") as raw:
        meta = json.loads(raw.read())

    archive.close()

    # Installs dependencies
    print("Installing Dependencies")
    for i in meta["dependencies"]:
        os.system("pip install " + i)

    os.chdir("../")

    end_time = time.time()
    print("Process finished in " + str(end_time - start_time) + " seconds.")
    return meta


def run(file, keep):
    meta = extract(file)

    try:
        os.system("python program/" + meta["main"])
    except:  # noqa: E722
        print(
            "An error occured in the program. Please contact the developer.",
            file=sys.stderr,
        )

    if keep is False:
        shutil.rmtree("program")


def press(path):
    start_time = time.time()
    os.chdir(path)

    print("Reading press.json")
    with open("press.json") as raw:
        meta = json.loads(raw.read())

    include = []
    include.append(meta["main"])
    include.append("press.json")
    for i in meta["dependencies"]:
        if os.path.isfile(i):
            include.append(i)

    for i in meta["include"]:
        include.append(i)

    print("Writing .press file")
    program = ZipFile("program.press", mode="w")
    for i in include:
        program.write(i)
    program.close()

    end_time = time.time()
    print("Process finished in " + str(end_time - start_time) + " seconds.")



import setuptools


with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="presspy",
    version="1.0.0",
    author="BD103",
    author_email="dont@stalk.me",
    description="A Python Compression Software",
    long_description=long_description,  # Keep
    long_description_content_type="text/markdown",
    url="https://github.com/BD103/PressPy",
    packages=setuptools.find_packages(),
    install_requires=["click"],
    entry_points={"console_scripts": ["presspy=presspy.cli:cli"]},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Development Status :: 1 - Planning",
    ],
    python_requires=">=3.7",
)
